﻿// InputBox Example, Version 1.0.0, vom 10.09.2013
//
// Demo Projekt für eine Inputbox unter C#
//
// Copyright by Frank Schöneck, 2013
// letzte Änderung: Frank Schöneck, 10.09.2013 V1.0.0, Projektbeginn
//
// für Eplan Electric P8, ab V2.2
//

using System.Drawing;

public class FrankS_Inputbox
{

	[Start]
	public void Demo_InputBox()
	{
		string value = "Vorbelegung des Input";
		if (InputBox.Show("title", "promptText", ref value) == DialogResult.OK)
		{
			MessageBox.Show(value, "MessageBoxTitle", MessageBoxButtons.OK, MessageBoxIcon.Information);
		}
		return;
	}
}

public class InputBox
{
	/// <summary>
	/// Displays a dialog with a prompt and textbox where the user can enter information
	/// </summary>
	/// <param name="title">Dialog title</param>
	/// <param name="promptText">Dialog prompt</param>
	/// <param name="value">Sets the initial value and returns the result</param>
	/// <returns>Dialog result</returns>
	public static DialogResult Show(string title, string promptText, ref string value)
	{
		Form form = new Form();
		Label label = new Label();
		TextBox textBox = new TextBox();
		Button buttonOk = new Button();
		Button buttonCancel = new Button();

		form.Text = title;
		label.Text = promptText;
		textBox.Text = value;

		buttonOk.Text = "OK";
		buttonCancel.Text = "Abbrechen";
		buttonOk.DialogResult = DialogResult.OK;
		buttonCancel.DialogResult = DialogResult.Cancel;

		label.SetBounds(9, 18, 372, 13);
		textBox.SetBounds(12, 36, 372, 20);
		buttonOk.SetBounds(228, 72, 75, 23);
		buttonCancel.SetBounds(309, 72, 75, 23);

		label.AutoSize = true;
		textBox.Anchor = textBox.Anchor | AnchorStyles.Right;
		buttonOk.Anchor = AnchorStyles.Bottom | AnchorStyles.Right;
		buttonCancel.Anchor = AnchorStyles.Bottom | AnchorStyles.Right;

		form.ClientSize = new Size(396, 107);
		form.Controls.AddRange(new Control[] { label, textBox, buttonOk, buttonCancel });
		form.ClientSize = new Size(Math.Max(300, label.Right + 10), form.ClientSize.Height);
		form.FormBorderStyle = FormBorderStyle.FixedDialog;
		form.StartPosition = FormStartPosition.CenterScreen;
		form.MinimizeBox = false;
		form.MaximizeBox = false;
		form.AcceptButton = buttonOk;
		form.CancelButton = buttonCancel;

		DialogResult dialogResult = form.ShowDialog();
		value = textBox.Text;
		return dialogResult;
	}
}